const { useState, useEffect } = React;

function ChallengeBox() {
	const [wert, setWert] = useState('');
	const [nachgeladenerWert, setNachgeladenerWert] = useState('');
	const [bisDatum, setBisDatum] = useState('');
	const [isCFError, setIsCFError] = useState(true);
	const [isQRLoading, setIsQRLoading] = useState(false);
	const [partnerID, setPartnerID] = useState('');
	const [firstLoadReady, setFirstLoadReady] = useState(false);

	const translation = {
		de: {
			noPartnerID: 'Fehler: keine Partner-ID',
			PassPhrase: 'Gib hier Deinen Code ein',
			Check: 'Code überprüfen',
			Eingangspunkt: 'Gutschrift mit QR-Code einlösen',
			HierKlicken: 'Gutschrift jetzt einlösen',
			CodeGilt: `Dein Code <code class="myCodeBorder">${nachgeladenerWert}</code> gilt bis<br />${bisDatum}.`
		},
		en: {
			noPartnerID: 'Error: no Partner-ID',
			PassPhrase: 'Enter your code here',
			Check: 'Check code',
			Eingangspunkt: 'Redeem credit with QR code',
			HierKlicken: 'Redeem credit now',
			CodeGilt: `Your code <code class="myCodeBorder">${nachgeladenerWert}</code> is valid until<br />${bisDatum}.`
		},
		fr: {
			noPartnerID: 'Erreur: pas de Partner-ID',
			PassPhrase: 'Saisis ton code ici',
			Check: 'Vérifier le code',
			Eingangspunkt: 'Encaisser un crédit avec un code QR',
			HierKlicken: 'Utiliser un crédit maintenant',
			CodeGilt: `Ton code <code class="myCodeBorder">${nachgeladenerWert}</code> est valable jusqu\'à<br />${bisDatum}.`
		},
		it: {
			noPartnerID: 'Errore: nessun ID partner',
			PassPhrase: 'Inserisci il tuo codice qui',
			Check: 'Codice di controllo',
			Eingangspunkt: 'Riscuotere il credito con il codice QR',
			HierKlicken: 'Riscuotete ora il credito',
			CodeGilt: `Il codice <code class="myCodeBorder">${nachgeladenerWert}</code> è valido fino al<br />${bisDatum}.`
		}
	}

	useEffect(() => {
		fetch('/wp-json/upway_REST/getkid', {
			method: 'POST',
			headers: {
			'Content-Type': 'application/x-www-form-urlencoded',
			},
			body: 'WPPID=' + encodeURIComponent(WPPID),
		})
		.then((response) => response.json())
		.then((data) => {
			setPartnerID(data.KID);
			setFirstLoadReady(true);
		})
		.catch((error) => console.error('Fehler beim Abrufen des KID', error));
	}, []);
  
	if (!partnerID){
		if (firstLoadReady){
			return translation[THISLANG].noPartnerID;
		}
		else {
			return <span id="spinner"></span>
		}
	}

	const handleInputChange = (e) => {
		setWert(e.target.value);
	};

	const handleNachladenClick = () => {
		setIsCFError(false);
		setIsQRLoading(true);
		fetch('/wp-json/upway_REST/nachladen', {
			method: 'POST',
			headers: {
				'Content-Type': 'application/x-www-form-urlencoded',
			},
			body: 'buyerID=' + encodeURIComponent(partnerID) + '&friendlyName=' + encodeURIComponent(wert),
		})
		.then((response) => response.json())
		.then((QRValue) => {
			setIsQRLoading(false);
			if ((typeof QRValue === 'object') && (!Array.isArray(QRValue)) && (QRValue !== null) && (undefined !== QRValue.code)){
				setIsCFError(false);
				setNachgeladenerWert(QRValue.code);
			}
			else {
				setIsCFError(true);
				setNachgeladenerWert(QRValue);
			}
		})
		.catch((error) => {
			setIsQRLoading(false);
			console.error('Fehler beim key laden:', error);
		});
	};

	const Upway_Response_Box = () => {
		const currentDate = new Date();
		const futureDate = new Date();
		futureDate.setHours(currentDate.getHours() + 24);
		const dateOptions = {
			weekday: 'long',
			year: 'numeric',
			month: 'long',
			day: 'numeric',
			hour: 'numeric',
			minute: 'numeric',
		};
		setBisDatum(futureDate.toLocaleDateString(THISLANG, dateOptions));

  		const QRLink = 'https://'+UWCS+'/claim?accessCode='+encodeURIComponent(nachgeladenerWert);
		const IMGLink = PDIR + 'qrcode.php?CFV=' + btoa(QRLink);

		const SwitchQRDIV = () => {
			let o = document.getElementById('upway_response_switch');
			if (o != null){
				o.style.display = 'none';
			}
			o = document.getElementById('upway_response_qr');
			if (o != null){
				o.style.display = 'block';
			}
		}

		return (
			<div>
				<div id="upway_target" className="mt2">
					{isCFError ? nachgeladenerWert :				
					<div id="upway_response_box">
						<button className="brxe-button bricks-button lg bricks-background-primary m1" onClick={() => top.location.href=QRLink}>
							{translation[THISLANG].HierKlicken}
						</button><br />
						<div id="upway_response_switch" style={{display:'block'}}>
							<a className="colorLink" href="#" onClick={() => SwitchQRDIV()}>
								{translation[THISLANG].Eingangspunkt}
							</a>
						</div>
						<div id="upway_response_qr" style={{display:'none'}}>
							<img src={`${IMGLink}`} />
						</div>
						<div className="giltbox" dangerouslySetInnerHTML={{ __html: translation[THISLANG].CodeGilt }} />
					</div>}
				</div>
			</div>
		)
	}

	return (
		<div>
			{((!nachgeladenerWert || isCFError) && firstLoadReady) &&
			<div>
				{isQRLoading ?
					<span id="spinner"></span>
				:
					<div>
						<label className="dib" style={{color:'var(--fbc-primary-text)'}}>{translation[THISLANG].PassPhrase}:
							<input type="text" className="mr2 ml1 wa" value={wert} onChange={handleInputChange} size="40" />
						</label>
						<button className="brxe-button bricks-button lg bricks-background-secondary" onClick={handleNachladenClick}> {translation[THISLANG].Check} </button>
					</div>
				}
			</div>}
			{ nachgeladenerWert && <Upway_Response_Box /> }
		</div>
	);
}

ReactDOM.render(<ChallengeBox />, document.getElementById('upway_challenge_div'));
